==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebColumnResizeEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnResizeEventArgsDetailDescription } from "./WebColumnResizeEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnResizeEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnResizeEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnResizeEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnResizeEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnResizeEventArgsDetailDescriptionMetadata.c(WebColumnResizeEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebColumnResizeEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnResizeEventArgsDetailDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnResizeEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Column", "ExportedType:WebColumn");
            a.item("PrevWidth", "String");
            a.item("NewWidth", "String");
        }
        static d(a) {
            WebColumnResizeEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebColumnResizeEventArgsDetail", () => new WebColumnResizeEventArgsDetailDescription());
            a.z("WebColumnResizeEventArgsDetail", WebColumnResizeEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnResizeEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnResizeEventArgsDetailDescriptionMetadata, 'WebColumnResizeEventArgsDetailDescriptionMetadata');
    WebColumnResizeEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnResizeEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnResizeEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnResizeEventArgsDetailDescription } from "./WebColumnResizeEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnResizeEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnResizeEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnResizeEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnResizeEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnResizeEventArgsDetailDescriptionMetadata.c(WebColumnResizeEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnResizeEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnResizeEventArgsDetailDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnResizeEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Column", "ExportedType:WebColumn");
            a.item("PrevWidth", "String");
            a.item("NewWidth", "String");
        }
        static d(a) {
            WebColumnResizeEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebColumnResizeEventArgsDetail", () => new WebColumnResizeEventArgsDetailDescription());
            a.ab("WebColumnResizeEventArgsDetail", WebColumnResizeEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnResizeEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnResizeEventArgsDetailDescriptionMetadata, 'WebColumnResizeEventArgsDetailDescriptionMetadata');
    WebColumnResizeEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnResizeEventArgsDetailDescriptionMetadata;
})();
